@@ -89,6 +89,14 @@ void	config(int argc, char **argv)
 			{
 				trust_db_port = htons(atoi(pnt));
 			}
+                        else if (!memcmp (buff, "NODE_ADAPTER_VENDOR_ID", 22))
+                        {
+                                NodeVendorID = atoi(pnt);
+                        }
+			else if (!memcmp (buff, "NODE_ADAPTER_PRODUCT_ID", 23))
+                        {
+                                NodeProductID = atoi(pnt);
+                        }
 		}
 	}
 	fclose (config_file);
