@@ -8,6 +8,8 @@
 	2014.01.23 V00.03 drop "htons"
 	2014.01.23 V00.04 Added RnRoute messages routine
 	2014.01.28 V00.05 Changed "hole punching" routine & bug fixed
+	2014.01.29 V00.06 Added PacketID check
+	2014.01.30 V00.07 Added ProductID & Vendor ID set routine
 */
 
 #include <stdio.h>
@@ -24,6 +26,7 @@
 #include <pthread.h>
 #include <errno.h>
 #include "dsgwd_pi.h"
+#include "node.h"
 
 void	exit (int status);
 void	*node_adapter (void *arg);
@@ -63,6 +66,7 @@ char	RelaySW;
 char	respFlags;
 char	Connected;
 char	DVwait;
+unsigned char	PacketIdSave[2];
 
 char	PTT_On;
 char	COS_On;
@@ -103,7 +107,8 @@ void	send_dsvt(void)
         		sndAddr.sin_family = PF_INET;
         		sndAddr.sin_port = trust_db_port;
         		sndAddr.sin_addr = dbIP;
-        		sendto (udpSocket, (char *)&RelayPacket, sizeof(RelayPacket), 0,
+        		sendto (udpSocket, (char *)&RelayPacket, 
+				sizeof(RelayPacket), 0,
                 		(struct sockaddr *)&sndAddr, sizeof(sndAddr));
 		}
 		else
@@ -132,14 +137,16 @@ void	send_dsvt(void)
 			}
 			if (RelaySW)
 			{
-                        	memcpy ((char *)&RelayPacket.dv, (char *)&send_pkt, 27);
+                        	memcpy ((char *)&RelayPacket.dv, 
+					(char *)&send_pkt, 27);
                         	RelayPacket.ip = dstIP;
                         	RelayPacket.port = dstPort;
                         	sndAddr.sin_family = PF_INET;
                         	sndAddr.sin_port = trust_db_port;
                         	sndAddr.sin_addr = dbIP;
                         	sendto (udpSocket, (char *)&RelayPacket, 33, 0,
-                                	(struct sockaddr *)&sndAddr, sizeof(sndAddr));
+                                	(struct sockaddr *)&sndAddr, 
+					sizeof(sndAddr));
 			}
 			else
 			{
@@ -147,7 +154,8 @@ void	send_dsvt(void)
                 		sndAddr.sin_port = dstPort;
                 		sndAddr.sin_family = PF_INET;
         			sendto (udpSocket, &send_pkt, 27, 0,
-               				(struct sockaddr *)&sndAddr, sizeof(sndAddr));
+               				(struct sockaddr *)&sndAddr, 
+					sizeof(sndAddr));
 			}
 			if (send_pkt.B_header.seq & 0x40)
 			{
@@ -196,14 +204,15 @@ void	receive_dsvt(void)
 		}
         }
 
-	if (memcmp ((char *)&inet_recv.ID, STREAM_ID, 4) == 0)
+	if (!memcmp ((char *)&inet_recv.ID, STREAM_ID, 4) 
+		&& !memcmp(&PacketIdSave, &inet_recv.B_header.PacketID, 2))
 	{
 		mq_send (inet_qid, (char *)&inet_recv, sizeof(inet_recv), 1);
 		DVwait = FALSE;
 	}
 }
 
-void	AckSendTrust(char srcRptCall[8])
+void	AckSendTrust(char srcRptCall[8], char PacketID[2] )
 {
         struct  shm_form        ack_msg;
 
@@ -213,6 +222,8 @@ void	AckSendTrust(char srcRptCall[8])
         sndAddr.sin_family = PF_INET;
         sndAddr.sin_port = trust_db_port;
 	sndAddr.sin_addr = dbIP;
+        ack_msg.PacketID[0] = PacketID[0];
+        ack_msg.PacketID[1] = PacketID[1];
         sendto (udpSocket, (char *)&ack_msg, sizeof(ack_msg), 0,
                  (struct sockaddr *)&sndAddr, sizeof(sndAddr));
 	return;
@@ -246,11 +257,14 @@ void	ConSend(void)
 {
         memcpy (&send_msg.Rep2Call, &send_pkt.header.Rpt2Call, 32);
 	memcpy (&send_msg.dstRep, &send_pkt.header.YourCall, 8);
-
 	send_msg.type = ReqConnect;
 	send_msg.protocol = G3;
 	send_msg.PacketID[0] = send_pkt.B_header.PacketID[0];
         send_msg.PacketID[1] = send_pkt.B_header.PacketID[1];
+	PacketIdSave[0] = send_pkt.B_header.PacketID[0];
+	PacketIdSave[1] = send_pkt.B_header.PacketID[1];
+	send_msg.PacketID[0] = PacketIdSave[0];
+	send_msg.PacketID[1] = PacketIdSave[1];
 	sndAddr.sin_family = PF_INET;
 	sndAddr.sin_port = trust_db_port;
 	sndAddr.sin_addr = dbIP;
@@ -307,10 +321,11 @@ int main(int argc, const char **argv)
 	Connected = FALSE;
 	DSTREQcnt = 0;
 	DVwait = FALSE;
+	NodeVendorID =  VendorID;
+	NodeProductID = ProductID;
 
 	config (argc, (char **)argv);
 
-printf ("debug repeater mode %d\n",repeater_mode);
 	if (cmdmode == 0)
 	{
 		cmdin = 0;
@@ -445,11 +460,11 @@ printf ("debug repeater mode %d\n",repeater_mode);
 				if (ConnectWait)
 				{
 					AckTimeOut++;
-					if (AckTimeOut == 40)	/* 100 m sec, */
+					if (AckTimeOut == 20)	/* 100 m sec, */
 					{
 						ConSend();
 					}
-					if (AckTimeOut > 80)	/* 200 m sec. */
+					if (AckTimeOut > 40)	/* 200 m sec. */
 					{
 						RelaySW = TRUE;
 						ConnectWait = FALSE;
@@ -486,7 +501,7 @@ printf ("debug repeater mode %d\n",repeater_mode);
                                         }
                         		if (reqConMsg.reqType == Ack)
                         		{
-						if (!Connected)
+						if (!Connected && !memcmp(&PacketIdSave, &reqConMsg.ackConnect.PacketID, 2))
 						{
 							dstPort = reqConMsg.ackConnect.port;
 							dstIP = reqConMsg.ackConnect.ip;
@@ -520,10 +535,12 @@ printf ("debug repeater mode %d\n",repeater_mode);
 						}
 						else
 						{
+							PacketIdSave[0] = reqConMsg.reqConnect.PacketID[0];
+							PacketIdSave[1] = reqConMsg.reqConnect.PacketID[1];
 							ReqSendSender();
 							DVwait = TRUE;
 							DSTREQcnt = 0;
-							AckSendTrust (reqConMsg.reqConnect.Rpt1Call);
+							AckSendTrust (reqConMsg.reqConnect.Rpt1Call, reqConMsg.reqConnect.PacketID);
 						}
                         		}
 				}
