@@ -82,6 +82,7 @@ void	ConSend(void);
 #define	STREAM_ID	"DSVT"
 #define	TRUE	1
 #define	FALSE	0
+
 struct	repMsg
 {
 	unsigned char		reqType;		/* 0x00: NoEntry    */
@@ -195,3 +196,5 @@ char		repeater_mode;
 
 struct	packet	dv_frame;
 
+unsigned	int	NodeVendorID;
+unsigned	int	NodeProductID;
